==> mlr_2.7.tar.gz: mlr/R/RLearner_classif_gaterSVM.R <==
#' @export
makeRLearner.classif.gaterSVM = function() {
  makeRLearnerClassif(
    cl = "classif.gaterSVM",
    package = c("SwarmSVM", "e1071"),
    par.set = makeParamSet(
      makeIntegerLearnerParam(id = "m", default = 3, lower = 1),
      makeNumericLearnerParam(id = "c", default = 1, lower = 0),
      makeIntegerLearnerParam(id = "max.iter", default = 1, lower = 1),
      makeIntegerLearnerParam(id = "hidden", default = 5, lower = 0),
      makeNumericLearnerParam(id = "learningrate", default = 0.01, lower = 0),
      makeNumericLearnerParam(id = "threshold", default = 0.01, lower = 0),
      makeIntegerLearnerParam(id = "stepmax", default = 100, lower = 1),
      makeNumericLearnerParam(id = "seed"),
      makeUntypedLearnerParam(id = "valid.x", default = NULL),
      makeUntypedLearnerParam(id = "valid.y", default = NULL),
      makeUntypedLearnerParam(id = "valid.metric", default = NULL),
      makeLogicalLearnerParam(id = "verbose", default = FALSE)
    ),
    par.vals = list(m = 3, max.iter = 1),
    properties = c("twoclass", "numerics"),
    name = "Mixture of SVMs with Neural Network Gater Function",
    short.name = "gaterSVM",
    note = "m set to 3 and max.iter set to 1 by default"
  )
}

#' @export
trainLearner.classif.gaterSVM = function(.learner, .task, .subset, .weights = NULL, ...) {
  d = getTaskData(.task, .subset, target.extra = TRUE)
  SwarmSVM::gaterSVM(x = d$data, y = d$target, ...)
}

#' @export
predictLearner.classif.gaterSVM = function(.learner, .model, .newdata, ...) {
  factor(predict(.model$learner.model, newdata = .newdata, ...),
    labels = .model$factor.levels$Class)
}

==> mlr_2.8.tar.gz: mlr/R/RLearner_classif_gaterSVM.R <==
#' @export
makeRLearner.classif.gaterSVM = function() {
  makeRLearnerClassif(
    cl = "classif.gaterSVM",
    package = c("SwarmSVM", "e1071"),
    par.set = makeParamSet(
      makeIntegerLearnerParam(id = "m", default = 3, lower = 1),
      makeNumericLearnerParam(id = "c", default = 1, lower = 0),
      makeIntegerLearnerParam(id = "max.iter", default = 1, lower = 1),
      makeIntegerLearnerParam(id = "hidden", default = 5, lower = 0),
      makeNumericLearnerParam(id = "learningrate", default = 0.01, lower = 0),
      makeNumericLearnerParam(id = "threshold", default = 0.01, lower = 0),
      makeIntegerLearnerParam(id = "stepmax", default = 100, lower = 1),
      makeNumericLearnerParam(id = "seed"),
      makeUntypedLearnerParam(id = "valid.x", default = NULL),
      makeUntypedLearnerParam(id = "valid.y", default = NULL),
      makeUntypedLearnerParam(id = "valid.metric", default = NULL),
      makeLogicalLearnerParam(id = "verbose", default = FALSE)
    ),
    par.vals = list(m = 3, max.iter = 1),
    properties = c("twoclass", "numerics"),
    name = "Mixture of SVMs with Neural Network Gater Function",
    short.name = "gaterSVM",
    note = "`m` set to `3` and `max.iter` set to `1` by default."
  )
}

#' @export
trainLearner.classif.gaterSVM = function(.learner, .task, .subset, .weights = NULL, ...) {
  d = getTaskData(.task, .subset, target.extra = TRUE)
  SwarmSVM::gaterSVM(x = d$data, y = d$target, ...)
}

#' @export
predictLearner.classif.gaterSVM = function(.learner, .model, .newdata, ...) {
  factor(predict(.model$learner.model, newdata = .newdata, ...),
    labels = .model$factor.levels$Class)
}
